@@ -10,7 +10,7 @@ use UNIVERSAL::Object::Immutable;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.11';
+our $VERSION   = '0.12';
 our $AUTHORITY = 'cpan:STEVAN';
 
 our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object::Immutable' }
@@ -26,11 +26,11 @@ sub BUILDARGS {
         $args = $class->SUPER::BUILDARGS( @_ );
     }
 
-    Carp::croak('[ARGS] You must specify a slot name')
+    Carp::confess('[ARGS] You must specify a slot name')
         unless $args->{name};
-    Carp::croak('[ARGS] You must specify a slot initializer')
+    Carp::confess('[ARGS] You must specify a slot initializer')
         unless $args->{initializer};
-    Carp::croak('[ARGS] The initializer specified must be a CODE reference')
+    Carp::confess('[ARGS] The initializer specified must be a CODE reference')
         unless ref $args->{initializer} eq 'CODE'
             || MOP::Internal::Util::CAN_COERCE_TO_CODE_REF( $args->{initializer} );
 
@@ -76,7 +76,7 @@ sub origin_stash {
 sub was_aliased_from {
     my ($self, @classnames) = @_;
 
-    Carp::croak('[ARGS] You must specify at least one classname')
+    Carp::confess('[ARGS] You must specify at least one classname')
         if scalar( @classnames ) == 0;
 
     my $class = $self->origin_stash;
@@ -98,7 +98,7 @@ MOP::Slot - A representation of a class slot
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
