@@ -8,12 +8,15 @@ use MOP::Role;
 use MOP::Class;
 use MOP::Internal::Util ();
 
-our $VERSION   = '0.11';
+our $VERSION   = '0.12';
 our $AUTHORITY = 'cpan:STEVAN';
 
 sub get_meta {
     my ($package) = @_;
 
+    return $package->METACLASS->new( $package )
+        if $package->can('METACLASS');
+
     my $meta = MOP::Role->new( $package );
     my $isa  = MOP::Internal::Util::GET_GLOB_SLOT( $meta->stash, 'ISA', 'ARRAY' );
 
@@ -49,10 +52,11 @@ sub inherit_slots {
         # will gives us *all* the slots, including
         # those that are themselves inherited ...
         foreach my $slot ( $super->all_slots ) {
+            my $slot_name = $slot->name;
             # we always just alias this anyway ...
-            $meta->alias_slot( $slot->name, $slot->initializer )
-                unless $meta->has_slot( $slot->name )
-                    || $meta->has_slot_alias( $slot->name );
+            $meta->alias_slot( $slot_name, $slot->initializer )
+                unless $meta->has_slot( $slot_name )
+                    || $meta->has_slot_alias( $slot_name );
         }
     }
 
@@ -79,7 +83,7 @@ MOP::Util - For MOP External Use Only
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
@@ -91,15 +95,24 @@ This is a public API of MOP related utility functions.
 
 =item C<get_meta( $package )>
 
-This will guess the most sensible type of meta object to represent
-the C<$package> supplied. The test is simple, if there is anything
-in the C<@ISA> array within C<$package>, then it is clearly a class
-and therefore returns a L<MOP::Class> instance. However, if there
-is nothing in C<@ISA> we conservatively estimate that this is a role
-and return a L<MOP::Role> instance.
+First this will check to see if C<$package> has a C<METACLASS>
+method, and if so, will use it to construct the metaclass and
+return it to you.
+
+If no C<METACLASS> method is found, this function will next attempt
+to guess the most sensible type of meta object for the C<$package>
+supplied.
+
+The test is simple, if there is anything in the C<@ISA> array inside
+C<$package>, then it is clearly a class and then this function returns
+a L<MOP::Class> instance. However, if there is nothing in C<@ISA> we
+conservatively estimate that this is a role and then return a
+L<MOP::Role> instance.
 
 In pretty much all cases that matter, a role and a class are entirely
-interchangable.
+interchangable. The only real difference is that a class has methods
+in the MOP for manipulating inheritance relationships (C<@ISA>)and
+roles do not.
 
 =item C<compose_roles( $meta )>
 
